@@ -1,3 +1,6 @@
+// https://github.com/rust-lang/rust/issues/88621
+#![feature(arbitrary_enum_discriminant)]
+
 // TODO: `module` to `pallet`
 
 #[cfg(feature = "simple")]
